==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CheckboxChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckboxChangeEventArgsDescription } from "./CheckboxChangeEventArgsDescription";
/**
 * @hidden
 */
var CheckboxChangeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CheckboxChangeEventArgsDescriptionMetadata, _super);
    function CheckboxChangeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CheckboxChangeEventArgsDescriptionMetadata.b = function (a) {
        if (CheckboxChangeEventArgsDescriptionMetadata.a == null) {
            CheckboxChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CheckboxChangeEventArgsDescriptionMetadata.c(CheckboxChangeEventArgsDescriptionMetadata.a);
        }
        if (a.g(CheckboxChangeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(CheckboxChangeEventArgsDescriptionMetadata.a);
    };
    CheckboxChangeEventArgsDescriptionMetadata.c = function (a) {
        a.item("IsChecked", "Boolean");
        a.item("IsIndeterminate", "Boolean");
    };
    CheckboxChangeEventArgsDescriptionMetadata.d = function (a) {
        CheckboxChangeEventArgsDescriptionMetadata.b(a);
        a.u("CheckboxChangeEventArgs", function () { return new CheckboxChangeEventArgsDescription(); });
        a.t("CheckboxChangeEventArgs", CheckboxChangeEventArgsDescriptionMetadata.a);
    };
    CheckboxChangeEventArgsDescriptionMetadata.$t = markType(CheckboxChangeEventArgsDescriptionMetadata, 'CheckboxChangeEventArgsDescriptionMetadata');
    CheckboxChangeEventArgsDescriptionMetadata.a = null;
    return CheckboxChangeEventArgsDescriptionMetadata;
}(Base));
export { CheckboxChangeEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CheckboxChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckboxChangeEventArgsDescription } from "./CheckboxChangeEventArgsDescription";
/**
 * @hidden
 */
var CheckboxChangeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CheckboxChangeEventArgsDescriptionMetadata, _super);
    function CheckboxChangeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CheckboxChangeEventArgsDescriptionMetadata.b = function (a) {
        if (CheckboxChangeEventArgsDescriptionMetadata.a == null) {
            CheckboxChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CheckboxChangeEventArgsDescriptionMetadata.c(CheckboxChangeEventArgsDescriptionMetadata.a);
        }
        if (a.j(CheckboxChangeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(CheckboxChangeEventArgsDescriptionMetadata.a);
    };
    CheckboxChangeEventArgsDescriptionMetadata.c = function (a) {
        a.item("IsChecked", "Boolean");
        a.item("IsIndeterminate", "Boolean");
    };
    CheckboxChangeEventArgsDescriptionMetadata.d = function (a) {
        CheckboxChangeEventArgsDescriptionMetadata.b(a);
        a.aa("CheckboxChangeEventArgs", function () { return new CheckboxChangeEventArgsDescription(); });
        a.z("CheckboxChangeEventArgs", CheckboxChangeEventArgsDescriptionMetadata.a);
    };
    CheckboxChangeEventArgsDescriptionMetadata.$t = markType(CheckboxChangeEventArgsDescriptionMetadata, 'CheckboxChangeEventArgsDescriptionMetadata');
    CheckboxChangeEventArgsDescriptionMetadata.a = null;
    return CheckboxChangeEventArgsDescriptionMetadata;
}(Base));
export { CheckboxChangeEventArgsDescriptionMetadata };
